# History

## 0.0.1 (2021-06-14)

* First release on PyPI.

## 0.0.2 (2021-06-18)

* Bugfix.

## 0.0.3 (2021-08-19)

* Support auto discoverable endpoints.
* Handle requests to unavailable microservices.
* Improve request forwarding to microservices.
* Fix bug related with unnecessary `json` casting.

## 0.0.4 (2021-08-54)
* Add support to `CORS`.
